export declare class MessageUtil {
    /**
     * Get the message for a given key
     * @param key The key of the message
     * @param tokens The values to substitute in the message
     */
    static get(key: string, tokens?: Array<string | number | boolean>): string;
    /**
     * Get the description used in the --help output for the command
     * @param descriptionKey The message key for the description text
     * @param isLightningBundle If the command is for a lightning bundle
     * @param tokens The values to substitute in the message
     * @param extra Extra text to append to the description at the end
     */
    static buildDescription(descriptionKey: string, isLightningBundle: boolean, tokens?: Array<string | number | boolean>, extra?: string): string;
    /**
     * Get the help text displayed in site documentation for the command
     *
     * **USE `buildDescription` FOR SETTING THE `description` PROPERTY OF
     * A COMMAND. THIS IS EXCLUSIVELY USED TO SET THE `help` PROPERTY ON THE COMMAND FOR
     * DOC GENERATING PURPOSES AND IS NOT SHOWN IN THE --help OUTPUT.**
     * @param examples Example uses of the command
     * @param isLightningBundle If the command is for a lightning bundle
     * @param extra Extra text to append to the help message before the examples
     */
    static buildHelpText(examples: string[], isLightningBundle: boolean, extra?: string): string;
    private static messages;
    private static getHelpHead;
}
